# `name` is the name of the package as used for `pip install package`
name = "rc-repo-utils"
# `path` is the name of the package for `import package`
# path = name.lower().replace("-", "_").replace(" ", "_")
path = "repo_utils"
# Your version number should follow https://python.org/dev/peps/pep-0440 and
# https://semver.org
version = "0.1.dev5"
author = "Joshua Mathias"
author_email = "joshuaamathias@gmail.com"
description = "Repository utilities to facilitate collaborative and modularized coding."  # One-liner
url = ""  # your project homepage
license = "MIT"  # See https://choosealicense.com
